@@ -57,8 +57,11 @@ func dotWalker(data map[DotNodes]bool, tgtOrig string) (map[DotNodes]bool, error
 			data[DotNodes{tgtOrig, cwdMustRel(cwd, m["Target"])}] = true
 		case DepTypeIfchange:
 			dep = m["Target"]
+			if dep == tgt {
+				continue
+			}
 			data[DotNodes{tgtOrig, cwdMustRel(cwd, dep)}] = false
-			if isSrc(cwd, dep) || dep == tgt {
+			if isSrc(cwd, dep) {
 				continue
 			}
 			data, err = dotWalker(data, cwdMustRel(cwd, dep))
