@@ -43,6 +43,7 @@ var InodeTrust InodeTrustType
 
 type Inode struct {
 	Size      int64
+	InodeNum  uint64
 	CtimeSec  int64
 	CtimeNsec int64
 	MtimeSec  int64
@@ -53,6 +54,9 @@ func (our *Inode) Equals(their *Inode) bool {
 	if our.Size != their.Size {
 		return false
 	}
+	if our.InodeNum != their.InodeNum {
+		return false
+	}
 	switch InodeTrust {
 	case InodeTrustCtime:
 		if our.CtimeSec != their.CtimeSec || our.CtimeNsec != their.CtimeNsec {
@@ -72,6 +76,7 @@ func (our *Inode) Equals(their *Inode) bool {
 func (inode *Inode) RecfileFields() []recfile.Field {
 	return []recfile.Field{
 		{Name: "Size", Value: strconv.FormatInt(inode.Size, 10)},
+		{Name: "InodeNum", Value: strconv.FormatUint(inode.InodeNum, 10)},
 		{Name: "CtimeSec", Value: strconv.FormatInt(inode.CtimeSec, 10)},
 		{Name: "CtimeNsec", Value: strconv.FormatInt(inode.CtimeNsec, 10)},
 		{Name: "MtimeSec", Value: strconv.FormatInt(inode.MtimeSec, 10)},
@@ -95,6 +100,7 @@ func inodeFromFile(fd *os.File) (*Inode, error) {
 	mtimeNsec := fi.ModTime().UnixNano()
 	return &Inode{
 		Size:     fi.Size(),
+		InodeNum: uint64(stat.Ino),
 		CtimeSec: ctimeSec, CtimeNsec: ctimeNsec,
 		MtimeSec: mtimeSec, MtimeNsec: mtimeNsec,
 	}, nil
@@ -102,6 +108,7 @@ func inodeFromFile(fd *os.File) (*Inode, error) {
 
 func inodeFromRec(m map[string]string) (*Inode, error) {
 	size := m["Size"]
+	inodeNum := m["InodeNum"]
 	ctimeSec := m["CtimeSec"]
 	ctimeNsec := m["CtimeNsec"]
 	mtimeSec := m["MtimeSec"]
@@ -121,6 +128,12 @@ func inodeFromRec(m map[string]string) (*Inode, error) {
 	if err != nil {
 		return nil, err
 	}
+	if inodeNum != "" {
+		inode.InodeNum, err = strconv.ParseUint(inodeNum, 10, 64)
+		if err != nil {
+			return nil, err
+		}
+	}
 	inode.CtimeSec, err = strconv.ParseInt(ctimeSec, 10, 64)
 	if err != nil {
 		return nil, err
