@@ -194,6 +194,15 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		return TgtError{tgtOrig, err}
 	}
 
+	shCtx := fmt.Sprintf("sh: %s: cwd:%s", tgtOrig, cwd)
+	jsToken := jsAcquire(shCtx)
+	jsNeedsRelease := true
+	defer func() {
+		if jsNeedsRelease {
+			jsRelease(shCtx, jsToken)
+		}
+	}()
+
 	// Acquire lock
 	fdLock, err := os.OpenFile(
 		path.Join(redoDir, tgt+LockSuffix),
@@ -265,6 +274,7 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		Finish:
 			if err != nil {
 				err = TgtError{tgtOrig, err}
+				fdLock.Close()
 			}
 			errs <- err
 		}()
@@ -380,6 +390,10 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		path.Join(dirPrefix, basename),
 		tmpPathRel,
 	)
+	shCtx = fmt.Sprintf(
+		"sh: %s: %s %s cwd:%s dirprefix:%s",
+		tgtOrig, cmdName, args, cwd, dirPrefix,
+	)
 
 	cmd := exec.Command(cmdName, args...)
 	cmd.Dir = cwd
@@ -422,15 +436,11 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 			return TgtError{tgtOrig, err}
 		}
 	}
-	shCtx := fmt.Sprintf(
-		"sh: %s: %s %s cwd:%s dirprefix:%s",
-		tgtOrig, cmdName, args, cwd, dirPrefix,
-	)
 	tracef(CDebug, "%s", shCtx)
 
+	jsNeedsRelease = false
 	Jobs.Add(1)
 	go func() {
-		jsToken := jsAcquire(shCtx)
 		if JSR == nil {
 			// infinite jobs
 			cmd.Env = append(cmd.Env, fmt.Sprintf("%s=NO", EnvJobs))
@@ -452,12 +462,17 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 			}
 		}
 
+		defer jsRelease(shCtx, jsToken)
+
 		var finished time.Time
 		var exitErr *exec.ExitError
 		started := time.Now()
 		runErr.Started = &started
 		fdStdout, err = os.OpenFile(stdoutPath, os.O_RDWR, os.FileMode(0666))
 		if err != nil {
+			if fdStderr != nil {
+				fdStderr.Close()
+			}
 			runErr.Err = err
 			errs <- runErr
 			return
@@ -465,6 +480,10 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		cmd.Stdout = fdStdout
 		fdDep, err = os.OpenFile(fdDepPath, os.O_WRONLY|os.O_APPEND, os.FileMode(0666))
 		if err != nil {
+			if fdStderr != nil {
+				fdStderr.Close()
+			}
+			fdStdout.Close()
 			runErr.Err = err
 			errs <- runErr
 			return
@@ -475,7 +494,6 @@ func runScript(tgtOrig string, errs chan error, traced bool) error {
 		cmd.Env = append(cmd.Env, fmt.Sprintf("%s=%s", EnvDepCwd, cwd))
 
 		defer func() {
-			jsRelease(shCtx, jsToken)
 			fdDep.Close()
 			fdStdout.Close()
 			if fdStderr != nil {
